@@ -43,7 +43,7 @@ package Astro::Coord::ECI::Moon;
 use strict;
 use warnings;
 
-our $VERSION = '0.064_01';
+our $VERSION = '0.064_03';
 
 use base qw{Astro::Coord::ECI};
 
@@ -483,7 +483,7 @@ eod
 
 # The moon is normally positioned in inertial coordinates.
 
-sub _initial_inertial { return 1 }
+sub __initial_inertial { return 1 }
 
 1;
 
